# Generated by Django 4.2 on 2023-07-19 11:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailimagecaptions", "0001_initial"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="ExtendedRendition",
            new_name="CaptionedRendition",
        ),
    ]
