# Generated by Django 5.1 on 2024-11-29 13:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailimagecaptions", "0006_alter_captionedimage_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="captionedimage",
            name="description",
            field=models.CharField(blank=True, default="", max_length=255, verbose_name="description"),
        ),
    ]
