# Generated by Django 4.2 on 2023-11-21 11:28

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailimagecaptions", "0002_rename_extendedrendition_captionedrendition"),
    ]

    operations = [
        migrations.AddField(
            model_name="captionedimage",
            name="byline",
            field=models.CharField(blank=True, help_text="The name(s) of the creator(s) of the image.", max_length=255),
        ),
        migrations.AddField(
            model_name="captionedimage",
            name="copyright_notice",
            field=models.CharField(blank=True, help_text="Any necessary copyright notice(s).", max_length=255),
        ),
        migrations.AddField(
            model_name="captionedimage",
            name="usage_terms",
            field=models.CharField(
                blank=True,
                help_text="Rights information and usage limitations associated with the image, including any special restrictions or instructions.",
                max_length=255,
            ),
        ),
        migrations.AddField(
            model_name="captionedimage",
            name="uuid",
            field=models.UUIDField(db_index=True, default=uuid.uuid4, null=True),
        ),
        migrations.AlterField(
            model_name="captionedimage",
            name="credit",
            field=models.CharField(
                blank=True, help_text="The name of the provider (e.g. AP, Getty, Reuters).", max_length=255
            ),
        ),
    ]
